@@ -52,12 +52,12 @@ impl OpenConnect {
 
         // Allow input to and output from open ports (for port forwarding in tunnel)
         if let Some(opens) = open_ports {
-            super::util::open_ports(&netns, opens.as_slice(), firewall)?;
+            super::util::open_ports(netns, opens.as_slice(), firewall)?;
         }
 
         // Allow input to and output from forwarded ports
         if let Some(forwards) = forward_ports {
-            super::util::open_ports(&netns, forwards.as_slice(), firewall)?;
+            super::util::open_ports(netns, forwards.as_slice(), firewall)?;
         }
 
         Ok(Self { pid: id })
