@@ -35,8 +35,8 @@ impl OpenVpnProvider for NordVPN {
         Ok((username, password))
     }
 
-    fn auth_file_path(&self) -> anyhow::Result<PathBuf> {
-        Ok(self.openvpn_dir()?.join("auth.txt"))
+    fn auth_file_path(&self) -> anyhow::Result<Option<PathBuf>> {
+        Ok(Some(self.openvpn_dir()?.join("auth.txt")))
     }
 
     fn create_openvpn_config(&self) -> anyhow::Result<()> {
@@ -131,8 +131,11 @@ impl OpenVpnProvider for NordVPN {
 
         // Write OpenVPN credentials file
         let (user, pass) = self.prompt_for_auth()?;
-        let mut outfile = File::create(self.auth_file_path()?)?;
-        write!(outfile, "{}\n{}", user, pass)?;
+        let auth_file = self.auth_file_path()?;
+        if auth_file.is_some() {
+            let mut outfile = File::create(auth_file.unwrap())?;
+            write!(outfile, "{}\n{}", user, pass)?;
+        }
         Ok(())
     }
 }
